@@ -1,6 +1,6 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
- /* @(#) $Header: /sources/phpprintipp/phpprintipp/http_class.php,v 1.10 2008/05/14 23:30:41 harding Exp $
+ /* @(#) $Header: /sources/phpprintipp/phpprintipp/http_class.php,v 1.11 2008/05/20 22:39:54 harding Exp $
  *
  *
  * Class http_class - Basic http client with "Basic" authorization mechanism.
@@ -151,6 +151,7 @@ class http_class {
         
         $url = split (':',$url,2);
         $transport_type = $url[0];
+        $unix = false;
         switch($transport_type) {
                 case 'http':
                     $transport_type = 'tcp://';
@@ -158,25 +159,35 @@ class http_class {
                 case 'https':
                     $transport_type = 'tls://';
                     break;
+                case 'unix':
+                    $transport_type = 'unix://';
+                    $port = 0;
+                    $unix = true;
+                    break;
+                default:
+                    $transport_type = 'tcp://';
+                    break;
             }
         $url = $url[1];
-        $url = split("/",preg_replace("#^/{1,}#",'',$url),2);
-        $url = $url[0];
-        $port = $this->port;
-        $error = sprintf(_("Cannot resolve url: %s"),$url);
-        $ip = gethostbyname($url);
-        $ip = @gethostbyaddr($ip);
-        if (!$ip)
-            if ($this->with_exceptions)
-                throw new httpException($error);
-            else
-            {
-                trigger_error($error,E_USER_WARNING);
-                return false;
-            }
-        if (strstr($url,":")) // we got an ipv6 address
-            if (!strstr($url,"[")) // it is not escaped
-                $url = sprintf("[%s]",$url);
+        if (!$unix) {
+            $url = split("/",preg_replace("#^/{1,}#",'',$url),2);
+            $url = $url[0];
+            $port = $this->port;
+            $error = sprintf(_("Cannot resolve url: %s"),$url);
+            $ip = gethostbyname($url);
+            $ip = @gethostbyaddr($ip);
+            if (!$ip)
+                if ($this->with_exceptions)
+                    throw new httpException($error);
+                else
+                {
+                    trigger_error($error,E_USER_WARNING);
+                    return false;
+                }
+            if (strstr($url,":")) // we got an ipv6 address
+                if (!strstr($url,"[")) // it is not escaped
+                    $url = sprintf("[%s]",$url);
+        }
         $this->connection = @fsockopen($transport_type.$url, $port, $errno, $errstr, $this->timeout);
         $error = sprintf (_('Unable to connect to "%s%s port %s": %s'),
             $transport_type,
